---
name: Bug report
about: Report a bug or problem
title: "Bug report: "
labels: bug
assignees: ""
---

**Expected behavior**
A clear and concise description of what you expected to happen.

**Describe the problem**
A clear and concise description of the bug or problem (i.e. what actually happens).

**To reproduce**
Steps to reproduce the behavior:

1. Run function/notebook '....'
2. See error '....'
3. A minimum reproducible code example is greatly appreciated!

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment:**

- OS: [e.g. Linux, Windows]
- `eo-tides` version: [e.g. `v0.1.0`]

**Additional context**
Add any other context about the problem here.
